package com.ruoyi.basetyre.mapper;

import java.util.List;
import com.ruoyi.basetyre.domain.BaseCar;

/**
 * 车辆基础信息Mapper接口
 * 
 * @author Yangwl
 * @date 2023-02-08
 */
public interface BaseCarMapper 
{
    /**
     * 查询车辆基础信息
     * 
     * @param id 车辆基础信息主键
     * @return 车辆基础信息
     */
    public BaseCar selectBaseCarById(String id);

    /**
     * 查询车辆基础信息列表
     * 
     * @param baseCar 车辆基础信息
     * @return 车辆基础信息集合
     */
    public List<BaseCar> selectBaseCarList(BaseCar baseCar);

    /**
     * 新增车辆基础信息
     * 
     * @param baseCar 车辆基础信息
     * @return 结果
     */
    public int insertBaseCar(BaseCar baseCar);

    /**
     * 修改车辆基础信息
     * 
     * @param baseCar 车辆基础信息
     * @return 结果
     */
    public int updateBaseCar(BaseCar baseCar);

    /**
     * 删除车辆基础信息
     * 
     * @param id 车辆基础信息主键
     * @return 结果
     */
    public int deleteBaseCarById(String id);

    /**
     * 批量删除车辆基础信息
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBaseCarByIds(String[] ids);

    List<BaseCar> queryList(BaseCar baseCar);
}
